@@ -14,7 +14,6 @@ names <- c("a", "b", "c", "d")
 term_n <- c(0, 1, 1, 2)
 tform <- c("loglin", "lin", "lin", "plin")
 modelform <- "M"
-fir <- 0
 
 a_n <- c(0.1, 0.1, 0.1, 0.1)
 
@@ -53,12 +52,11 @@ event <- "Cancer_Status"
 
 ## -----------------------------------------------------------------------------
 keep_constant <- c(0, 0, 0, 0)
-der_iden <- 0
 
 control <- list(
   "ncores" = 1, "lr" = 0.75, "maxiter" = 100, "halfmax" = 5, "epsilon" = 1e-3,
-  "dbeta_max" = 0.5, "deriv_epsilon" = 1e-3, "abs_max" = 1.0, "change_all" = TRUE,
-  "dose_abs_max" = 100.0, "verbose" = FALSE, "ties" = "breslow", "double_step" = 1
+  "dbeta_max" = 0.5, "deriv_epsilon" = 1e-3, "abs_max" = 1.0,
+  "dose_abs_max" = 100.0, "verbose" = 2, "ties" = "breslow", "double_step" = 1
 )
 
 ## -----------------------------------------------------------------------------
@@ -66,7 +64,7 @@ control <- list(
 
 e <- RunCoxRegression(
   df, time1, time2, event, names, term_n, tform, keep_constant,
-  a_n, modelform, fir, der_iden, control
+  a_n, modelform, control
 )
 Interpret_Output(e)
 
